compute_max_from_total_system_mem

Function compute_max_from_total_system_mem 

fn compute_max_from_total_system_mem(
    mem: Result<usize, MemQueryError>,
) -> ByteQty
Determine a max given the system’s total available memory.

This is used when max is configured as “auto”. It takes a Result so that we can handle the case where the total memory isn’t available.