total_available_memory

Function total_available_memory 

fn total_available_memory() -> Result<usize, MemQueryError>
The total available memory in bytes.

This is generally the amount of system RAM, but we may also take into account other OS-specific limits such as cgroups.

Returns None if we were unable to get the total available memory. But see internal comments for details.