DropStatus

Trait DropStatus 

trait DropStatus {
    // Required method
    fn drop_status(status: Status);
}
Core of Drop, that can be called separately, for testing

To use: implement this, and derive deftly BombImpls.

Required Methods

fn drop_status(status: Status)

Handles dropping of a Self with this status field value

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors