pub(crate) enum IfEnabled<T> {
Enabled(T, EnabledToken),
Noop,
}Expand description
Either T, if we’re enabled, or nothing if we’re no-op
Used for runtime control of whether the memory quota is enabled:
we support explicitly creating a no-op tracker
with MemoryQuotaTracker::new_noop.
We use this rather than just Option because we also have data structures
(trackers, Accounts and so on)
which have been torn down, or are “dummy” or “dangling”,
which are supposed to return errors rather than no-op successes.
Variants
Enabled(T, EnabledToken)
We’re enabled, and supposed to be tracking memory
The 2nd member causes this variant to prove that tracking is enabled.
If tracking is disabled at compile time, this variant is uninhabited
and the whole IfEnabled becomes a unit.
Noop
We’re inenabled and everything should be a lightweight no-op
Implementations
Sourceimpl<T> IfEnabled<T>
impl<T> IfEnabled<T>
Sourcepub(crate) fn into_enabled(self) -> Option<T>
pub(crate) fn into_enabled(self) -> Option<T>
Convert to Option: return Some if this is Enabled
Sourcepub(crate) fn as_enabled(&self) -> Option<&T>
pub(crate) fn as_enabled(&self) -> Option<&T>
Take reference and convert to Option
Convenience helper equivalent to .as_ref().into_enabled().
Sourcepub(crate) fn enabled_or_bug(self) -> Result<T, Bug>
pub(crate) fn enabled_or_bug(self) -> Result<T, Bug>
Return the contents of the Enabled, or declare it a Bug