Octal

Trait Octal 

1.0.0 · Source
pub trait Octal {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
o formatting.

The Octal trait should format its output as a number in base-8.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0o in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '52' in octal

assert_eq!(format!("{x:o}"), "52");
assert_eq!(format!("{x:#o}"), "0o52");

assert_eq!(format!("{:o}", -16), "37777777760");

Implementing Octal on a type:

use std::fmt;

struct Length(i32);

impl fmt::Octal for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Octal::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(9);

assert_eq!(format!("l as octal is: {l:o}"), "l as octal is: 11");

assert_eq!(format!("l as octal is: {l:#06o}"), "l as octal is: 0o0011");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Octal for i8

1.0.0 · Source

impl Octal for i16

1.0.0 · Source

impl Octal for i32

1.0.0 · Source

impl Octal for i64

1.0.0 · Source

impl Octal for i128

1.0.0 · Source

impl Octal for isize

1.0.0 · Source

impl Octal for u8

1.0.0 · Source

impl Octal for u16

1.0.0 · Source

impl Octal for u32

1.0.0 · Source

impl Octal for u64

1.0.0 · Source

impl Octal for u128

1.0.0 · Source

impl Octal for usize

Source

impl Octal for u1

Source

impl Octal for u2

Source

impl Octal for u3

Source

impl Octal for u4

Source

impl Octal for u5

Source

impl Octal for u6

Source

impl Octal for u7

Source

impl Octal for u24

Source

impl Octal for u40

Source

impl Octal for u48

Source

impl Octal for u56

Source

impl Octal for EventMask

Source

impl Octal for WatchMask

Source

impl Octal for EventKindMask

Source

impl Octal for BigInt

Source

impl Octal for BigUint

Source

impl Octal for CipherCtxFlags

Source

impl Octal for CMSOptions

Source

impl Octal for OcspFlag

Source

impl Octal for Pkcs7Flags

Source

impl Octal for ExtensionContext

Source

impl Octal for ShutdownState

Source

impl Octal for SslMode

Source

impl Octal for SslOptions

Source

impl Octal for SslSessionCacheMode

Source

impl Octal for SslVerifyMode

Source

impl Octal for X509CheckFlags

Source

impl Octal for X509VerifyFlags

Source

impl Octal for rustix::backend::event::epoll::CreateFlags

Source

impl Octal for EventFlags

Source

impl Octal for PollFlags

Source

impl Octal for EventfdFlags

Source

impl Octal for rustix::backend::fs::inotify::CreateFlags

Source

impl Octal for ReadFlags

Source

impl Octal for WatchFlags

Source

impl Octal for Access

Source

impl Octal for AtFlags

Source

impl Octal for FallocateFlags

Source

impl Octal for MemfdFlags

Source

impl Octal for Mode

Source

impl Octal for OFlags

Source

impl Octal for RenameFlags

Source

impl Octal for ResolveFlags

Source

impl Octal for SealFlags

Source

impl Octal for StatVfsMountFlags

Source

impl Octal for DupFlags

Source

impl Octal for FdFlags

Source

impl Octal for ReadWriteFlags

Source

impl Octal for RecvFlags

Source

impl Octal for ReturnFlags

Source

impl Octal for SendFlags

Source

impl Octal for PipeFlags

Source

impl Octal for SpliceFlags

Source

impl Octal for TimerfdFlags

Source

impl Octal for TimerfdTimerFlags

Source

impl Octal for IFlags

Source

impl Octal for StatxAttributes

Source

impl Octal for StatxFlags

Source

impl Octal for XattrFlags

Source

impl Octal for SocketFlags

Source

impl Octal for TxTimeFlags

Source

impl Octal for SocketAddrXdpFlags

Source

impl Octal for XdpDescOptions

Source

impl Octal for XdpOptionsFlags

Source

impl Octal for XdpRingFlags

Source

impl Octal for XdpUmemRegFlags

Source

impl Octal for Pid

Source

impl Octal for PidfdFlags

Source

impl Octal for PidfdGetfdFlags

Source

impl Octal for FloatingPointEmulationControl

Source

impl Octal for FloatingPointExceptionMode

Source

impl Octal for SpeculationFeatureControl

Source

impl Octal for SpeculationFeatureState

Source

impl Octal for UnalignedAccessControl

Source

impl Octal for WaitIdOptions

Source

impl Octal for WaitOptions

Source

impl Octal for ControlModes

Source

impl Octal for InputModes

Source

impl Octal for LocalModes

Source

impl Octal for OutputModes

Source

impl Octal for Gid

Source

impl Octal for Uid

Source

impl<'a, I> Octal for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Octal,

Source

impl<O> Octal for I16<O>
where O: ByteOrder,

Source

impl<O> Octal for I32<O>
where O: ByteOrder,

Source

impl<O> Octal for I64<O>
where O: ByteOrder,

Source

impl<O> Octal for I128<O>
where O: ByteOrder,

Source

impl<O> Octal for Isize<O>
where O: ByteOrder,

Source

impl<O> Octal for U16<O>
where O: ByteOrder,

Source

impl<O> Octal for U32<O>
where O: ByteOrder,

Source

impl<O> Octal for U64<O>
where O: ByteOrder,

Source

impl<O> Octal for U128<O>
where O: ByteOrder,

Source

impl<O> Octal for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Octal for &T
where T: Octal + ?Sized,

1.0.0 · Source

impl<T> Octal for &mut T
where T: Octal + ?Sized,

Source

impl<T> Octal for crypto_bigint::non_zero::NonZero<T>
where T: Octal + Zero,

Source

impl<T> Octal for crypto_bigint::wrapping::Wrapping<T>
where T: Octal,

Source

impl<T> Octal for BoxSensitive<T>
where T: Octal,

Source

impl<T> Octal for Sensitive<T>
where T: Octal,

1.28.0 · Source

impl<T> Octal for core::num::nonzero::NonZero<T>

1.74.0 · Source

impl<T> Octal for Saturating<T>
where T: Octal,

1.11.0 · Source

impl<T> Octal for core::num::wrapping::Wrapping<T>
where T: Octal,