pub struct TrySendError<T> {
err: SendError,
val: T,
}Expand description
The error type returned from try_send.
Fields
err: SendErrorval: TImplementations
Sourceimpl<T> TrySendError<T>
impl<T> TrySendError<T>
Sourcepub fn is_full(&self) -> bool
pub fn is_full(&self) -> bool
Returns true if this error is a result of the channel being full.
Sourcepub fn is_disconnected(&self) -> bool
pub fn is_disconnected(&self) -> bool
Returns true if this error is a result of the receiver being dropped.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns the message that was attempted to be sent but failed.
Sourcepub fn into_send_error(self) -> SendError
pub fn into_send_error(self) -> SendError
Drops the message and converts into a SendError.