pub(crate) struct SpawnError {
_priv: (),
}Expand description
An error that occurred during spawning.
Fields
_priv: ()Implementations
Sourceimpl SpawnError
impl SpawnError
Sourcepub fn shutdown() -> SpawnError
pub fn shutdown() -> SpawnError
Spawning failed because the executor has been shut down.
Sourcepub fn is_shutdown(&self) -> bool
pub fn is_shutdown(&self) -> bool
Check whether spawning failed to the executor being shut down.