pub(crate) struct StreamUnobtrusivePeeker<S>where
S: Stream,{
buffered: Option<<S as Stream>::Item>,
poll_waker: Option<Waker>,
inner: Option<S>,
}Expand description
Wraps Stream and provides \[poll_]peek and unobtrusive_peek
unobtrusive_peek
is callable in sync contexts, outside the reading task.
Like futures::stream::Peekable,
this has an async peek method, and poll_peek,
for use from the task that is also reading (via the Stream impl).
But, that type doesn’t have unobtrusive_peek.
One way to conceptualise this is that StreamUnobtrusivePeeker is dual-ported:
the two sets of APIs, while provided on the same type,
are typically called from different contexts.
Fields
buffered: Option<<S as Stream>::Item>poll_waker: Option<Waker>inner: Option<S>Implementations
Sourceimpl<S> StreamUnobtrusivePeeker<S>where
S: Stream,
impl<S> StreamUnobtrusivePeeker<S>where
S: Stream,
Sourcepub fn new(inner: S) -> StreamUnobtrusivePeeker<S>
pub fn new(inner: S) -> StreamUnobtrusivePeeker<S>
Create a new StreamUnobtrusivePeeker from a Stream
Sourceimpl<S> StreamUnobtrusivePeeker<S>where
S: Stream,
impl<S> StreamUnobtrusivePeeker<S>where
S: Stream,
Sourcepub fn peek(
self: Pin<&mut StreamUnobtrusivePeeker<S>>,
) -> PeekFuture<'_, StreamUnobtrusivePeeker<S>> ⓘ
pub fn peek( self: Pin<&mut StreamUnobtrusivePeeker<S>>, ) -> PeekFuture<'_, StreamUnobtrusivePeeker<S>> ⓘ
Wait for an item to be ready, and then inspect it
Equivalent to futures::stream::Peekable::peek.
Tasks, waking, and calling context
This should be called by the task that is reading from the stream. If it is called by another task, the reading task would miss notifications.
Sourcepub fn as_raw_inner_pin_mut<'s>(
self: Pin<&'s mut StreamUnobtrusivePeeker<S>>,
) -> Option<Pin<&'s mut S>>
pub fn as_raw_inner_pin_mut<'s>( self: Pin<&'s mut StreamUnobtrusivePeeker<S>>, ) -> Option<Pin<&'s mut S>>
Obtain a raw reference to the inner stream
Correctness!
This method must be used with care! Whatever you do mustn’t interfere with polling and peeking. Careless use can result in wrong behaviour including deadlocks.