pub(super) struct ClaimedQty {
raw: ByteQty,
bomb: DropBombCondition,
}Expand description
“Cached” claim, on behalf of a Participant
Found in Participation.cache,
and accounted to the Participant (ie, included in ParticipQty).
Also used as a temporary variable in claim() and release() functions.
When we return to the participant, outside the tracker, we
essentially throw this away, since we don’t give the caller any representation
to store. The participant is supposed to track this separately somehow.
Fields
raw: ByteQtySee BookkeptQty
bomb: DropBombConditionSee BookkeptQty
Implementations
Sourceimpl ClaimedQty
impl ClaimedQty
Sourcepub(super) fn split_off(&mut self, want: Qty) -> Option<ClaimedQty>
pub(super) fn split_off(&mut self, want: Qty) -> Option<ClaimedQty>
Split a ClaimedQty into two ClaimedQtys
Sourcepub(super) fn merge_into(&mut self, have: ClaimedQty)
pub(super) fn merge_into(&mut self, have: ClaimedQty)
Merge two ClaimedQtys
(Handles overflow by saturating; returning an error is not going to be useful.)
Sourcepub(super) fn claim_return_to_participant(self) -> Result<()>
pub(super) fn claim_return_to_participant(self) -> Result<()>
Obtain result for the participant, after having successfully recorded the amount claimed
CORRECTNESS
This must be called only on a successful return path from Participation::claim.
Sourcepub(super) fn release_got_from_participant(got: Qty) -> Self
pub(super) fn release_got_from_participant(got: Qty) -> Self
When the participant indicates a release, enrol the amount in our bookkeeping scheme
Handles the quantity argument to Participation::release.
CORRECTNESS
This must be called only on entry to Participation::release.
Sourcepub(super) fn dispose_participant_destroyed(self)
pub(super) fn dispose_participant_destroyed(self)
Dispose of a quantity that was claimed by a now-destroyed participant
CORRECTNESS
The ParticipQty this was claimed from must also have been destroyed.
So,
ParticipQty::for_participant_teardown and the corresponding
release
must have been called earlier - possibly, much earlier.