pub(super) struct ParticipQty {
raw: ByteQty,
bomb: DropBombCondition,
}Expand description
Qty used by a participant, found in PRecord.used.
The tracker data structure has one of these for each Participant.
This is the total amount claimed, plus the caches in each Participation.
Fields
raw: ByteQtySee BookkeptQty
bomb: DropBombConditionSee BookkeptQty
Implementations
Sourceimpl ParticipQty
impl ParticipQty
Sourcepub(super) fn for_participant_teardown(&self) -> ClaimedQty
pub(super) fn for_participant_teardown(&self) -> ClaimedQty
Prepare to destroy the ParticipQty in a participant that’s being destroyed
When the records of a participant that is being torn down are being destroyed, we must remove our records of the memory that it allocated.
This function is for that situation.
The returned ClaimedQty should then be passed to release.
CORRECTNESS
The data structure where this ParticipQty resides
must be torn down (after we return).
The ClaimedQty must be passed to TotalQty::release.