inner_loop

Function inner_loop 

async fn inner_loop(
    tracker: &Arc<MemoryQuotaTracker>,
    _enabled: EnabledToken,
) -> Result<(), ReclaimCrashed>
Reclaim memory until we reach low water, if necessary

Looks to see if we’re above config.max. If so, constructs a list of victims, and starts reclaiming from them, until we reach low water.