NumParticips

Type Alias NumParticips 

type NumParticips = usize;
Total number of participants

Used in reporting and in calculations of various edge cases. On 64-bit systems, bigger than the refcounts, which are all u32