pub struct MemoryQuotaTracker {
state: IfEnabled<Mutex<State>>,
}Expand description
Memory data tracker
Instance of the memory quota system.
Usually found as Arc<MemoryQuotaTracker>.
Fields
state: IfEnabled<Mutex<State>>The actual tracker state etc.
Implementations
Sourceimpl MemoryQuotaTracker
impl MemoryQuotaTracker
Sourcepub fn new<R: Spawn>(
runtime: &R,
config: Config,
) -> Result<Arc<Self>, StartupError>
pub fn new<R: Spawn>( runtime: &R, config: Config, ) -> Result<Arc<Self>, StartupError>
Set up a new MemoryDataTracker
Sourcepub fn reconfigure(
&self,
new_config: Config,
how: Reconfigure,
) -> Result<(), ReconfigureError>
pub fn reconfigure( &self, new_config: Config, how: Reconfigure, ) -> Result<(), ReconfigureError>
Reconfigure
Sourcepub fn used_current_approx(&self) -> Result<usize, TrackerCorrupted>
pub fn used_current_approx(&self) -> Result<usize, TrackerCorrupted>
Returns an estimate of the total memory use
The returned value is:
- Approximate.
- A snapshot as of the current moment (and there is no way to await changes)
- Always
usize::MAXfor a no-op tracker
Sourcepub fn new_account(
self: &Arc<Self>,
parent: Option<&Account>,
) -> Result<Account>
pub fn new_account( self: &Arc<Self>, parent: Option<&Account>, ) -> Result<Account>
Make a new Account
To actually record memory usage, a Participant must be added.
At most call sites, take an Account rather than a MemoryQuotaTracker,
and use Account::new_child().
That improves the ability to manage the hierarchy of Participants.
Sourcepub fn new_noop() -> Arc<MemoryQuotaTracker> ⓘ
pub fn new_noop() -> Arc<MemoryQuotaTracker> ⓘ
Obtain a new MemoryQuotaTracker that doesn’t track anything and never reclaims
Sourcefn lock(&self) -> Result<IfEnabled<MutexGuard<'_, State>>, TrackerCorrupted>
fn lock(&self) -> Result<IfEnabled<MutexGuard<'_, State>>, TrackerCorrupted>
Obtain the lock on the state