#[repr(transparent)]struct PId(KeyData);Expand description
Identifies a Participant within an Account
Ie, PId is scoped within in the context of an account.
As with AId, a PId is invalid after the
participation is torn down, and is not reused.
Tuple Fields
0: KeyDataTrait Implementations
Sourceimpl<'de> Deserialize<'de> for PId
impl<'de> Deserialize<'de> for PId
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Key for PId
impl Key for PId
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for PId
impl Ord for PId
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for PId
impl PartialOrd for PId
impl Copy for PId
impl Eq for PId
impl StructuralPartialEq for PId