pub struct ParticipationInner {
pid: Ref<PId>,
aid: AId,
tracker: Weak<MemoryQuotaTracker>,
cache: ClaimedQty,
}Expand description
Contents of an enabled Participation
Fields
pid: Ref<PId>Participant id
aid: AIdAccount id
tracker: Weak<MemoryQuotaTracker>The underlying tracker
cache: ClaimedQtyQuota we have preemptively claimed for use by this Account
Has been added to PRecord.used,
but not yet returned by Participation::claim.
This cache field arranges that most of the time we don’t have to hammer a single cache line.
The value here is bounded by a configured limit.
Invariants on memory accounting:
Participation.cache < configured limitPRecord.used = Participation.cache + Σ Participation::claim - Σ P'n::releaseexcept ifPRecordhas been deleted (ie when we aren’t tracking any more and think the Participant isCollapsing).Σ PRecord.used = State.total_used
Enforcement of these invariants is partially assured by
types in bookkeeping.