TotalQtyNotifier

Struct TotalQtyNotifier 

pub(super) struct TotalQtyNotifier {
    total_used: TotalQty,
    reclamation_task_wakeup: Sender<()>,
}
Wrapper for TotalQty

Fields

total_used: TotalQty

Total memory usage

Invariant: equal to

   Σ        Σ         PRecord.used
    ARecord  PRecord
reclamation_task_wakeup: Sender<()>

Condvar to wake up the reclamation task

The reclamation task has another clone of this

Implementations

Source

impl TotalQtyNotifier

pub(super) fn new_zero(reclamation_task_wakeup: Sender<()>) -> Self

Make a new TotalQtyNotifier, which will notify a specified condvar

pub(super) fn claim( &mut self, precord: &mut PRecord, want: Qty, config: &ConfigInner, ) -> Result<ClaimedQty>

Record that some memory has been (or will be) allocated by a participant

Signals the wakeup task if we need to.

pub(super) fn maybe_wakeup(&mut self, config: &ConfigInner)

Check to see if we need to wake up the reclamation task, and if so, do so

pub(super) fn set_poisoned(&mut self)

Declare this poisoned, and prevent further claims

pub(super) fn release(&mut self, precord: &mut PRecord, have: ClaimedQty)

Record that some memory has been (or will be) freed by a participant