pub(crate) struct Ref<K: Key> {
raw_key: K,
marker: PhantomData<K>,
bomb: DropBombCondition,
}Expand description
An copy of a slotmap_careful::Key K, which is counted by a RefCount
Ie, a key of type K with the property that it
keeps the refcounted data structure alive.
Must always be deleted using dispose, not dropped.
In tests, dropping a RefCounted will panic.
The Default value does not contribute to a reference count,
and is fine to drop.
Fields
raw_key: KActual key (without generics)
marker: PhantomData<K>Bind to the specific key type
bomb: DropBombConditionDrop bomb
Also forces Ref not to be Clone
Implementations
Sourceimpl<K: Key> Ref<K>
impl<K: Key> Ref<K>
Sourcepub(crate) fn new(key: K, count: &mut Count<K>) -> Result<Self, Overflow>
pub(crate) fn new(key: K, count: &mut Count<K>) -> Result<Self, Overflow>
Create a refcounted reference Ref from an un-counted key, incrementing the count
Sourcepub(crate) fn null() -> Self
pub(crate) fn null() -> Self
Creates a null Ref, which doesn’t refer to any slot (lookups always give None)
Sourcepub(crate) fn dispose(self, refcount: &mut Count<K>) -> Option<Garbage<K>>
pub(crate) fn dispose(self, refcount: &mut Count<K>) -> Option<Garbage<K>>
Dispose of a refcounted reference Ref, decrementing the count
If the count reaches zero, the raw key is returned; the caller should remove the corresponding data from the data structure.
Sourcepub(crate) fn dispose_container_destroyed(self)
pub(crate) fn dispose_container_destroyed(self)
Dispose of a refcounted reference whose container no longer exists
CORRECTNESS
This just forgets the reference, without decrementing any refcount. If the container does still exist, a ref count ref will be leaked.