fn total_available_memory() -> Result<usize, MemQueryError>Expand description
The total available memory in bytes.
This is generally the amount of system RAM, but we may also take into account other OS-specific limits such as cgroups.
Returns None if we were unable to get the total available memory.
But see internal comments for details.