macro_rules! derive_deftly_template_QtySetters {
({ $($driver:tt)* } [$($aoptions:tt)*] ($($future:tt)*) $($tpassthrough:tt)*) => { ... };
($($wrong:tt)*) => { ... };
}Expand description
Define setters on the builder for every field of type Qty
The field type must be spelled precisely that way:
we use approx_equal(...).
This is a derive_deftly template. Do not invoke it directly.
To use it, write: #[derive(Deftly)] #[derive_deftly(QtySetters)].