Binary

Trait Binary 

1.0.0 · Source
pub trait Binary {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
b formatting.

The Binary trait should format its output as a number in binary.

For primitive signed integers (i8 to i128, and isize), negative values are formatted as the two’s complement representation.

The alternate flag, #, adds a 0b in front of the output.

For more information on formatters, see the module-level documentation.

Examples

Basic usage with i32:

let x = 42; // 42 is '101010' in binary

assert_eq!(format!("{x:b}"), "101010");
assert_eq!(format!("{x:#b}"), "0b101010");

assert_eq!(format!("{:b}", -16), "11111111111111111111111111110000");

Implementing Binary on a type:

use std::fmt;

struct Length(i32);

impl fmt::Binary for Length {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let val = self.0;

        fmt::Binary::fmt(&val, f) // delegate to i32's implementation
    }
}

let l = Length(107);

assert_eq!(format!("l as binary is: {l:b}"), "l as binary is: 1101011");

assert_eq!(
    // Note that the `0b` prefix added by `#` is included in the total width, so we
    // need to add two to correctly display all 32 bits.
    format!("l as binary is: {l:#034b}"),
    "l as binary is: 0b00000000000000000000000001101011"
);

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Implementors

1.0.0 · Source

impl Binary for i8

1.0.0 · Source

impl Binary for i16

1.0.0 · Source

impl Binary for i32

1.0.0 · Source

impl Binary for i64

1.0.0 · Source

impl Binary for i128

1.0.0 · Source

impl Binary for isize

1.0.0 · Source

impl Binary for u8

1.0.0 · Source

impl Binary for u16

1.0.0 · Source

impl Binary for u32

1.0.0 · Source

impl Binary for u64

1.0.0 · Source

impl Binary for u128

1.0.0 · Source

impl Binary for usize

Source

impl Binary for u1

Source

impl Binary for u2

Source

impl Binary for u3

Source

impl Binary for u4

Source

impl Binary for u5

Source

impl Binary for u6

Source

impl Binary for u7

Source

impl Binary for u24

Source

impl Binary for u40

Source

impl Binary for u48

Source

impl Binary for u56

Source

impl Binary for EventMask

Source

impl Binary for WatchMask

Source

impl Binary for EventKindMask

Source

impl Binary for BigInt

Source

impl Binary for BigUint

Source

impl Binary for CipherCtxFlags

Source

impl Binary for CMSOptions

Source

impl Binary for OcspFlag

Source

impl Binary for Pkcs7Flags

Source

impl Binary for ExtensionContext

Source

impl Binary for ShutdownState

Source

impl Binary for SslMode

Source

impl Binary for SslOptions

Source

impl Binary for SslSessionCacheMode

Source

impl Binary for SslVerifyMode

Source

impl Binary for X509CheckFlags

Source

impl Binary for X509VerifyFlags

Source

impl Binary for rustix::backend::event::epoll::CreateFlags

Source

impl Binary for EventFlags

Source

impl Binary for PollFlags

Source

impl Binary for EventfdFlags

Source

impl Binary for rustix::backend::fs::inotify::CreateFlags

Source

impl Binary for ReadFlags

Source

impl Binary for WatchFlags

Source

impl Binary for Access

Source

impl Binary for AtFlags

Source

impl Binary for FallocateFlags

Source

impl Binary for MemfdFlags

Source

impl Binary for Mode

Source

impl Binary for OFlags

Source

impl Binary for RenameFlags

Source

impl Binary for ResolveFlags

Source

impl Binary for SealFlags

Source

impl Binary for StatVfsMountFlags

Source

impl Binary for DupFlags

Source

impl Binary for FdFlags

Source

impl Binary for ReadWriteFlags

Source

impl Binary for RecvFlags

Source

impl Binary for ReturnFlags

Source

impl Binary for SendFlags

Source

impl Binary for PipeFlags

Source

impl Binary for SpliceFlags

Source

impl Binary for TimerfdFlags

Source

impl Binary for TimerfdTimerFlags

Source

impl Binary for IFlags

Source

impl Binary for StatxAttributes

Source

impl Binary for StatxFlags

Source

impl Binary for XattrFlags

Source

impl Binary for SocketFlags

Source

impl Binary for TxTimeFlags

Source

impl Binary for SocketAddrXdpFlags

Source

impl Binary for XdpDescOptions

Source

impl Binary for XdpOptionsFlags

Source

impl Binary for XdpRingFlags

Source

impl Binary for XdpUmemRegFlags

Source

impl Binary for Pid

Source

impl Binary for PidfdFlags

Source

impl Binary for PidfdGetfdFlags

Source

impl Binary for FloatingPointEmulationControl

Source

impl Binary for FloatingPointExceptionMode

Source

impl Binary for SpeculationFeatureControl

Source

impl Binary for SpeculationFeatureState

Source

impl Binary for UnalignedAccessControl

Source

impl Binary for WaitIdOptions

Source

impl Binary for WaitOptions

Source

impl Binary for ControlModes

Source

impl Binary for InputModes

Source

impl Binary for LocalModes

Source

impl Binary for OutputModes

Source

impl Binary for Gid

Source

impl Binary for Uid

Source

impl Binary for Z0

Source

impl Binary for UInt<UTerm, B0>

Source

impl Binary for UInt<UTerm, B1>

Source

impl Binary for UTerm

Source

impl<'a, I> Binary for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Binary,

Source

impl<O> Binary for I16<O>
where O: ByteOrder,

Source

impl<O> Binary for I32<O>
where O: ByteOrder,

Source

impl<O> Binary for I64<O>
where O: ByteOrder,

Source

impl<O> Binary for I128<O>
where O: ByteOrder,

Source

impl<O> Binary for Isize<O>
where O: ByteOrder,

Source

impl<O> Binary for U16<O>
where O: ByteOrder,

Source

impl<O> Binary for U32<O>
where O: ByteOrder,

Source

impl<O> Binary for U64<O>
where O: ByteOrder,

Source

impl<O> Binary for U128<O>
where O: ByteOrder,

Source

impl<O> Binary for Usize<O>
where O: ByteOrder,

1.0.0 · Source

impl<T> Binary for &T
where T: Binary + ?Sized,

1.0.0 · Source

impl<T> Binary for &mut T
where T: Binary + ?Sized,

Source

impl<T> Binary for crypto_bigint::non_zero::NonZero<T>
where T: Binary + Zero,

Source

impl<T> Binary for crypto_bigint::wrapping::Wrapping<T>
where T: Binary,

Source

impl<T> Binary for BoxSensitive<T>
where T: Binary,

Source

impl<T> Binary for Sensitive<T>
where T: Binary,

1.28.0 · Source

impl<T> Binary for core::num::nonzero::NonZero<T>

1.74.0 · Source

impl<T> Binary for Saturating<T>
where T: Binary,

1.11.0 · Source

impl<T> Binary for core::num::wrapping::Wrapping<T>
where T: Binary,

Source

impl<U> Binary for NInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U> Binary for PInt<U>
where U: Unsigned + NonZero + Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B0>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,

Source

impl<U, B> Binary for UInt<UInt<U, B>, B1>
where U: Unsigned, B: Bit, UInt<U, B>: Binary,