pub(super) struct GuardWithDeferredDrop<'m> {
guard: Option<MutexGuard<'m, State>>,
deferred_drop: Vec<ProtectedArc<dyn IsParticipant>>,
}Expand description
MutexGuard<State> but also a list of Arc<dyn Participant> to drop when we unlock
Fields
guard: Option<MutexGuard<'m, State>>The mutex guard
Always Some; just an Option so we can move out during drop
deferred_drop: Vec<ProtectedArc<dyn IsParticipant>>The participants we’ve acquired and which we want to drop later
Implementations
Sourceimpl<'m> GuardWithDeferredDrop<'m>
impl<'m> GuardWithDeferredDrop<'m>
Sourcepub(super) fn new(guard: MutexGuard<'m, State>) -> Self
pub(super) fn new(guard: MutexGuard<'m, State>) -> Self
Prepare for handling deferred drops
Sourcepub(super) fn deref_mut_both(
&mut self,
) -> (&mut State, &mut Vec<ProtectedArc<dyn IsParticipant>>)
pub(super) fn deref_mut_both( &mut self, ) -> (&mut State, &mut Vec<ProtectedArc<dyn IsParticipant>>)
Obtain mutable borrows of the two components
Methods from Deref<Target = State>
Sourcefn get_aid_and_children_recursively(&self, parent_aid: AId) -> HashSet<AId>
fn get_aid_and_children_recursively(&self, parent_aid: AId) -> HashSet<AId>
Obtain all of the descendants of parent_aid according to the Child relation
The returned HashSet includes parent_aid, its children,
their children, and so on.
Used in the reclamation algorithm in reclaim.
Sourcefn prepare_parent_aid(&mut self, parent: &Account) -> Result<AId>
fn prepare_parent_aid(&mut self, parent: &Account) -> Result<AId>
Find and check the requested parent’s account ID
This function is responsible for garbage collecting dead children
from parent’s children. On successful return, a new child
can be added without extending children.
This is called in preparation for adding another account
to parent’s list of child accounts.
Returns an error if the specified parent account is not enabled,
or if it has been torn down.