pub(super) struct TotalQtyNotifier {
total_used: TotalQty,
reclamation_task_wakeup: Sender<()>,
}Expand description
Wrapper for TotalQty
Fields
total_used: TotalQtyTotal memory usage
Invariant: equal to
Σ Σ PRecord.used
ARecord PRecordreclamation_task_wakeup: Sender<()>Condvar to wake up the reclamation task
The reclamation task has another clone of this
Implementations
Sourceimpl TotalQtyNotifier
impl TotalQtyNotifier
Sourcepub(super) fn new_zero(reclamation_task_wakeup: Sender<()>) -> Self
pub(super) fn new_zero(reclamation_task_wakeup: Sender<()>) -> Self
Make a new TotalQtyNotifier, which will notify a specified condvar
Sourcepub(super) fn claim(
&mut self,
precord: &mut PRecord,
want: Qty,
config: &ConfigInner,
) -> Result<ClaimedQty>
pub(super) fn claim( &mut self, precord: &mut PRecord, want: Qty, config: &ConfigInner, ) -> Result<ClaimedQty>
Record that some memory has been (or will be) allocated by a participant
Signals the wakeup task if we need to.
Sourcepub(super) fn maybe_wakeup(&mut self, config: &ConfigInner)
pub(super) fn maybe_wakeup(&mut self, config: &ConfigInner)
Check to see if we need to wake up the reclamation task, and if so, do so
Sourcepub(super) fn set_poisoned(&mut self)
pub(super) fn set_poisoned(&mut self)
Declare this poisoned, and prevent further claims
Sourcepub(super) fn release(&mut self, precord: &mut PRecord, have: ClaimedQty)
pub(super) fn release(&mut self, precord: &mut PRecord, have: ClaimedQty)
Record that some memory has been (or will be) freed by a participant